#!/bin/sh
# 
# Usage: ./mkdirs.sh [RELEASEPATH] [BASEPATH]
# Creates the release directory structure in the RELEASEPATH directory.
# The current directory is used by default.
# If BASEPATH is specified only directories that have a corresponding
# match in BASEPATH are created
# 
<<RELEASEINFO>>

RELEASEPATH=${1-.}
BASEPATH=${2}

NUMPATHS=<<NUMPATHS>>
NCREATED=0
NCHECKED=0

if [ -z "${BASEPATH}" ]; then
	# BASEPATH was not set -- A full release is created in RELEASEPATH
	echo "Creating ${NUMPATHS} paths in '${RELEASEPATH}'"
else
	echo "Creating up to ${NUMPATHS} paths in '${RELEASEPATH}' if they exist in '${BASEPATH}'"
fi

# Creates a path in RELEASEPATH
# $1 = The path to create (for example, /S000001/l.r.m.c.lib.g)
function createPath {
	NCHECKED=$(( ${NCHECKED} + 1 ))
	if [[ -z "${BASEPATH}" || -d "${BASEPATH}${1}" ]]; then
		echo "[${NCHECKED}/${NUMPATHS}] ${RELEASEPATH}${1}"
		mkdir -p ${RELEASEPATH}${1}
		NCREATED=$(( ${NCREATED} + 1 ))
	fi
}

<<SCRIPT>>

echo Done: ${NCREATED} paths created

